'use client';

import { useState, useEffect } from 'react';
import Link from 'next/link';
import Image from 'next/image';
import { auth } from '@/utils/firebase';
import { signOut } from 'firebase/auth';
import { useRouter } from 'next/navigation';

const Header = () => {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [user, setUser] = useState(auth.currentUser);
  const router = useRouter();

  useEffect(() => {
    const unsubscribe = auth.onAuthStateChanged((user) => {
      setUser(user);
    });

    return () => unsubscribe();
  }, []);

  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen);
  };

  const handleLogout = async () => {
    try {
      await signOut(auth);
      router.push('/');
    } catch (error) {
      console.error('Error signing out:', error);
    }
  };

  return (
    <header className="fixed top-0 left-0 right-0 bg-[#0a0a0a] z-50 border-b border-[#1a1a1a]">
      <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-20">
          {/* Logo */}
          <div className="flex-shrink-0 flex items-center group">
            <Link href="/" className="flex items-center space-x-3 hover:opacity-95 transition-all duration-300">
              <div className="relative">
                <div className="relative">
                  <Image
                    src="/edvolab_logo.png"
                    alt="EdvoLab Logo"
                    width={52}
                    height={52}
                    className="w-13 h-13 rounded-full transform group-hover:scale-105 transition-transform duration-300"
                    priority
                  />
                </div>
              </div>
              <div className="flex flex-col">
                <span className="text-2xl font-bold text-white">
                  Nomvate
                </span>
                <span className="text-sm text-[#FF6B00] font-medium tracking-wider">
                  by EdvoLab
                </span>
              </div>
            </Link>
          </div>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex items-center space-x-1">
            <Link href="/games" className="nav-link group">
              <span className="relative z-10">Games</span>
              <div className="absolute inset-0 bg-gradient-to-r from-[#0066FF]/0 via-[#FF6B00]/0 to-[#0066FF]/0 group-hover:from-[#0066FF]/10 group-hover:via-[#FF6B00]/10 group-hover:to-[#0066FF]/10 rounded-md transition-all duration-300"></div>
            </Link>
            <Link href="/about" className="nav-link group">
              <span className="relative z-10">About</span>
              <div className="absolute inset-0 bg-gradient-to-r from-[#0066FF]/0 via-[#FF6B00]/0 to-[#0066FF]/0 group-hover:from-[#0066FF]/10 group-hover:via-[#FF6B00]/10 group-hover:to-[#0066FF]/10 rounded-md transition-all duration-300"></div>
            </Link>
            <Link href="/contact" className="nav-link group">
              <span className="relative z-10">Contact</span>
              <div className="absolute inset-0 bg-gradient-to-r from-[#0066FF]/0 via-[#FF6B00]/0 to-[#0066FF]/0 group-hover:from-[#0066FF]/10 group-hover:via-[#FF6B00]/10 group-hover:to-[#0066FF]/10 rounded-md transition-all duration-300"></div>
            </Link>

            {/* Auth Buttons */}
            {user ? (
              <div className="flex items-center space-x-4">
                <Link href="/dashboard" className="nav-link group">
                  <span className="relative z-10">Dashboard</span>
                </Link>
                <button
                  onClick={handleLogout}
                  className="px-4 py-2 rounded-lg bg-gradient-to-r from-[#FF6B2B] to-[#FF8C37] text-white font-semibold hover:from-[#FF8C37] hover:to-[#FF6B2B] transition-all"
                >
                  Sign Out
                </button>
              </div>
            ) : (
              <div className="flex items-center">
                <Link
                  href="/login"
                  className="px-4 py-2 rounded-lg bg-gradient-to-r from-[#FF6B2B] to-[#FF8C37] text-white font-semibold hover:from-[#FF8C37] hover:to-[#FF6B2B] transition-all"
                >
                  Sign In
                </Link>
              </div>
            )}
          </nav>

          {/* Mobile Menu Button */}
          <div className="md:hidden">
            <button
              onClick={toggleMenu}
              className="relative inline-flex items-center justify-center p-2 rounded-md text-[#ededed] hover:text-[#FF6B00] focus:outline-none group"
              aria-expanded="false"
            >
              <div className="absolute inset-0 bg-gradient-to-r from-[#0066FF]/0 via-[#FF6B00]/0 to-[#0066FF]/0 group-hover:from-[#0066FF]/10 group-hover:via-[#FF6B00]/10 group-hover:to-[#0066FF]/10 rounded-md transition-all duration-300"></div>
              <span className="sr-only">Open main menu</span>
              {!isMenuOpen ? (
                <svg
                  className="block h-6 w-6 relative z-10"
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 24 24"
                  stroke="currentColor"
                >
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                    d="M4 6h16M4 12h16M4 18h16"
                  />
                </svg>
              ) : (
                <svg
                  className="block h-6 w-6 relative z-10"
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 24 24"
                  stroke="currentColor"
                >
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                    d="M6 18L18 6M6 6l12 12"
                  />
                </svg>
              )}
            </button>
          </div>
        </div>

        {/* Mobile Navigation */}
        <div
          className={`md:hidden ${
            isMenuOpen ? 'block' : 'hidden'
          } pb-4 pt-2 space-y-1`}
        >
          <div className="relative">
            <div className="absolute inset-0 bg-gradient-to-r from-[#0066FF]/5 via-[#FF6B00]/5 to-[#0066FF]/5 rounded-lg"></div>
            <div className="relative space-y-1 p-2 rounded-lg bg-[#0a0a0a]/90 backdrop-blur-sm">
              <Link
                href="/games"
                className="mobile-nav-link group"
                onClick={() => setIsMenuOpen(false)}
              >
                <span className="relative z-10">Games</span>
              </Link>
              <Link
                href="/about"
                className="mobile-nav-link group"
                onClick={() => setIsMenuOpen(false)}
              >
                <span className="relative z-10">About</span>
              </Link>
              <Link
                href="/contact"
                className="mobile-nav-link group"
                onClick={() => setIsMenuOpen(false)}
              >
                <span className="relative z-10">Contact</span>
              </Link>

              {/* Mobile Auth Buttons */}
              {user ? (
                <>
                  <Link
                    href="/dashboard"
                    className="mobile-nav-link group"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <span className="relative z-10">Dashboard</span>
                  </Link>
                  <button
                    onClick={() => {
                      handleLogout();
                      setIsMenuOpen(false);
                    }}
                    className="w-full text-left px-4 py-3 rounded-md text-[#FF6B2B] hover:text-[#FF8C37] font-medium transition-colors"
                  >
                    Sign Out
                  </button>
                </>
              ) : (
                <Link
                  href="/login"
                  className="mobile-nav-link group"
                  onClick={() => setIsMenuOpen(false)}
                >
                  <span className="relative z-10">Sign In</span>
                </Link>
              )}
            </div>
          </div>
        </div>
      </div>
    </header>
  );
};

export default Header; 